using System;
using System.IO;
using System.Collections;

namespace Classless.MXO.Blipper {
	/// <summary>Represents an entire blip file.</summary>
	public class BlipCollection {
		private ArrayList _blips;


		/// <summary>Gets the blips that are in the file.</summary>
		public ArrayList Blips {
			get { return _blips; }
		}


		/// <summary>Initializes a new instance of BlipCollection.</summary>
		public BlipCollection() {
			_blips = new ArrayList();
		}

		/// <summary>Initializes a new instance of BlipCollection.</summary>
		/// <param name="s">The stream to read the blip file contents from.</param>
		public BlipCollection(Stream s) {
			_blips = new ArrayList();

			// Find out how many blips we're dealing with.
			byte[] temp = new byte[2];
			s.Read(temp, 0, 2);
			ushort numBlips = BitConverter.ToUInt16(temp, 0);

			// Read in the blips.
			while (numBlips > 0) {
				Blips.Add(new Blip(s));
				numBlips--;
			}

			// Chew off the last 4 bytes.
			s.Seek(4, SeekOrigin.Current);
		}


		/// <summary>Writes the blip file to a stream.</summary>
		/// <param name="s">The stream to write to.</param>
		public void Write(Stream s) {
			// Figure out how many blips we'll be writing.
			ushort blipCount;
			if (Blips.Count > ushort.MaxValue) {
				blipCount = ushort.MaxValue;
			} else {
				blipCount = (ushort)(Blips.Count);
			}

			// Number of blips in file.
			s.Write(BitConverter.GetBytes(blipCount), 0, 2);

			// Write out the blips.
			ushort cnt = 0;
			foreach (Blip b in Blips) {
				b.Write(s);

				cnt++;
				if (cnt == blipCount) {
					// This makes sure we don't write more blips than are accounted for in the header.
					break;
				}
			}

			// 4 bytes of 00's.
			s.Write(new byte[]{ 0x00, 0x00, 0x00, 0x00 }, 0, 4);
		}
	}
}
