using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.Reflection;

namespace Classless.MXO.Blipper {
	/// <summary>A window that displays information about the program.</summary>
	public class FrmAbout : Form {
		#region Control Declarations
		private System.Windows.Forms.Label lblNameVersion;
		private System.Windows.Forms.Label lblDescription;
		private System.Windows.Forms.Label lblCopyright;
		private System.Windows.Forms.LinkLabel lblURL;
		private System.Windows.Forms.GroupBox groupBox1;
		private System.Windows.Forms.Button btnOK;
		private System.ComponentModel.Container components = null;
		#endregion


		/// <summary>Initializes a new instance of FrmAbout.</summary>
		public FrmAbout() {
			InitializeComponent();
			StartEventProcessing();

			// Get the information about this program.
			Assembly a = Assembly.GetExecutingAssembly();
			Version version = a.GetName().Version;
			AssemblyTitleAttribute title = (AssemblyTitleAttribute)AssemblyTitleAttribute.GetCustomAttribute(a, typeof(AssemblyTitleAttribute));
			AssemblyCopyrightAttribute copyright = (AssemblyCopyrightAttribute)AssemblyCopyrightAttribute.GetCustomAttribute(a, typeof(AssemblyCopyrightAttribute));
			AssemblyDescriptionAttribute description = (AssemblyDescriptionAttribute)AssemblyDescriptionAttribute.GetCustomAttribute(a, typeof(AssemblyDescriptionAttribute));

			// Display it.
			this.Text = "About " + title.Title;
			lblNameVersion.Text = title.Title + " v" + version.Major.ToString() + "." + version.Minor.ToString();
			lblDescription.Text = description.Description;
			lblCopyright.Text = "Copyright " + copyright.Copyright;
		}


		/// <summary>Clean up any resources being used.</summary>
		protected override void Dispose(bool disposing) {
			if ((disposing) && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}


		#region Events
		// Hook into the event processing.
		private void StartEventProcessing() {
			btnOK.Click += new EventHandler(btnOK_Click);
			lblURL.LinkClicked += new System.Windows.Forms.LinkLabelLinkClickedEventHandler(lblURL_LinkClicked);
		}

		// User wants to close this window.
		private void btnOK_Click(object sender, System.EventArgs e) {
			this.Close();
		}

		// User wants to visit the homepage.
		private void lblURL_LinkClicked(object sender, System.Windows.Forms.LinkLabelLinkClickedEventArgs e) {
			System.Diagnostics.Process.Start(lblURL.Text);
		}
		#endregion


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.lblNameVersion = new System.Windows.Forms.Label();
			this.lblDescription = new System.Windows.Forms.Label();
			this.lblCopyright = new System.Windows.Forms.Label();
			this.lblURL = new System.Windows.Forms.LinkLabel();
			this.groupBox1 = new System.Windows.Forms.GroupBox();
			this.btnOK = new System.Windows.Forms.Button();
			this.groupBox1.SuspendLayout();
			this.SuspendLayout();
			// 
			// lblNameVersion
			// 
			this.lblNameVersion.Location = new System.Drawing.Point(8, 20);
			this.lblNameVersion.Name = "lblNameVersion";
			this.lblNameVersion.Size = new System.Drawing.Size(176, 20);
			this.lblNameVersion.TabIndex = 0;
			// 
			// lblDescription
			// 
			this.lblDescription.Location = new System.Drawing.Point(8, 40);
			this.lblDescription.Name = "lblDescription";
			this.lblDescription.Size = new System.Drawing.Size(176, 20);
			this.lblDescription.TabIndex = 1;
			// 
			// lblCopyright
			// 
			this.lblCopyright.Location = new System.Drawing.Point(8, 60);
			this.lblCopyright.Name = "lblCopyright";
			this.lblCopyright.Size = new System.Drawing.Size(176, 20);
			this.lblCopyright.TabIndex = 2;
			// 
			// lblURL
			// 
			this.lblURL.Location = new System.Drawing.Point(8, 80);
			this.lblURL.Name = "lblURL";
			this.lblURL.Size = new System.Drawing.Size(176, 20);
			this.lblURL.TabIndex = 3;
			this.lblURL.TabStop = true;
			this.lblURL.Text = "http://mxo.classless.net";
			// 
			// groupBox1
			// 
			this.groupBox1.Controls.Add(this.lblNameVersion);
			this.groupBox1.Controls.Add(this.lblDescription);
			this.groupBox1.Controls.Add(this.lblCopyright);
			this.groupBox1.Controls.Add(this.lblURL);
			this.groupBox1.Location = new System.Drawing.Point(8, 8);
			this.groupBox1.Name = "groupBox1";
			this.groupBox1.Size = new System.Drawing.Size(192, 108);
			this.groupBox1.TabIndex = 4;
			this.groupBox1.TabStop = false;
			// 
			// btnOK
			// 
			this.btnOK.Location = new System.Drawing.Point(66, 124);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 0;
			this.btnOK.Text = "&OK";
			// 
			// FrmAbout
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.ClientSize = new System.Drawing.Size(206, 155);
			this.ControlBox = false;
			this.Controls.Add(this.btnOK);
			this.Controls.Add(this.groupBox1);
			this.FormBorderStyle = System.Windows.Forms.FormBorderStyle.FixedDialog;
			this.Name = "FrmAbout";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "About";
			this.groupBox1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	}
}
