using System;
using System.Drawing;
using System.Collections;
using System.ComponentModel;
using System.Windows.Forms;
using System.IO;

namespace Classless.MXO.Blipper {
	/// <summary>Summary description for FrmImport.</summary>
	public class FrmImport : Form {
		#region Control Declarations
		private System.Windows.Forms.ListView listBlips;
		private System.Windows.Forms.ColumnHeader colBlipsName;
		private System.Windows.Forms.ColumnHeader colBlipsDistrict;
		private System.Windows.Forms.ColumnHeader colBlipsX;
		private System.Windows.Forms.ColumnHeader colBlipsY;
		private System.Windows.Forms.ColumnHeader colBlipsZ;
		private System.Windows.Forms.Panel panel1;
		private System.Windows.Forms.Button btnOK;
		private System.Windows.Forms.Button btnCancel;
		private System.Windows.Forms.Button btnSelectAll;
		private System.Windows.Forms.Button btnSelectNone;
		private System.Windows.Forms.Button btnInvert;
		private System.ComponentModel.Container components = null;
		#endregion


		private BlipCollection _blipCollection;


		/// <summary>Gets the blips that the user has selected.</summary>
		public BlipCollection BlipCollection {
			get { return _blipCollection; }
		}


		/// <summary>Initializes a new instance of FrmImport.</summary>
		public FrmImport(string filename) {
			InitializeComponent();
			StartEventProcessing();

			_blipCollection = new BlipCollection();

			// Read in the file.
			FileStream fs = null;
			BlipCollection bc;
			try {
				fs = new FileStream(filename, FileMode.Open, FileAccess.Read, FileShare.Read);
				bc = new BlipCollection(fs);
			} catch {
				throw;
			} finally {
				if (fs != null) { fs.Close(); }
			}

			// Add the blips to the list.
			ListViewItem lvi;
			foreach (Blip b in bc.Blips) {
				lvi = new ListViewItem(b.Name);
				lvi.SubItems.Add(b.District.ToString());
				lvi.SubItems.Add(b.X.ToString());
				lvi.SubItems.Add(b.Y.ToString());
				lvi.SubItems.Add(b.Z.ToString());
				lvi.Tag = b;
				lvi.Checked = true;
				listBlips.Items.Add(lvi);
			}
		}


		/// <summary>Clean up any resources being used.</summary>
		protected override void Dispose(bool disposing) {
			if ((disposing) && (components != null)) {
				components.Dispose();
			}
			base.Dispose(disposing);
		}


		#region Events
		// Hook into the event processing.
		private void StartEventProcessing() {
			btnSelectAll.Click += new EventHandler(btnSelectAll_Click);
			btnSelectNone.Click += new EventHandler(btnSelectNone_Click);
			btnInvert.Click += new EventHandler(btnInvert_Click);
			btnOK.Click += new EventHandler(btnOK_Click);
			btnCancel.Click += new EventHandler(btnCancel_Click);
			listBlips.ItemCheck += new ItemCheckEventHandler(listBlips_ItemCheck);
		}

		// User wants to select all the blips in the list.
		private void btnSelectAll_Click(object sender, EventArgs e) {
			foreach (ListViewItem lvi in listBlips.Items) {
				lvi.Checked = true;
			}
		}

		// User wants to deselect all the blips in the list.
		private void btnSelectNone_Click(object sender, EventArgs e) {
			foreach (ListViewItem lvi in listBlips.Items) {
				lvi.Checked = false;
			}
		}

		// User wants to invert the selection in the list.
		private void btnInvert_Click(object sender, EventArgs e) {
			foreach (ListViewItem lvi in listBlips.Items) {
				lvi.Checked = !lvi.Checked;
			}
		}

		// User accepts the selections.
		private void btnOK_Click(object sender, EventArgs e) {
			if (listBlips.CheckedItems.Count < 1) {
				MessageBox.Show("You must select at least one blip to import.", "Import Blips");
				return;
			}

			this.DialogResult = DialogResult.OK;
			this.Close();
		}

		// User is cancelling the operation.
		private void btnCancel_Click(object sender, EventArgs e) {
			this.DialogResult = DialogResult.Cancel;
			this.Close();
		}

		// User toggles the selection of one of the blips in the list.
		private void listBlips_ItemCheck(object sender, ItemCheckEventArgs e) {
			if (e.NewValue == CheckState.Checked) {
				_blipCollection.Blips.Add(((Blip)listBlips.Items[e.Index].Tag));
			} else {
				_blipCollection.Blips.Remove(((Blip)listBlips.Items[e.Index].Tag));
			}
		}
		#endregion


		#region Windows Form Designer generated code
		/// <summary>
		/// Required method for Designer support - do not modify
		/// the contents of this method with the code editor.
		/// </summary>
		private void InitializeComponent()
		{
			this.listBlips = new System.Windows.Forms.ListView();
			this.colBlipsName = new System.Windows.Forms.ColumnHeader();
			this.colBlipsDistrict = new System.Windows.Forms.ColumnHeader();
			this.colBlipsX = new System.Windows.Forms.ColumnHeader();
			this.colBlipsY = new System.Windows.Forms.ColumnHeader();
			this.colBlipsZ = new System.Windows.Forms.ColumnHeader();
			this.panel1 = new System.Windows.Forms.Panel();
			this.btnOK = new System.Windows.Forms.Button();
			this.btnCancel = new System.Windows.Forms.Button();
			this.btnSelectAll = new System.Windows.Forms.Button();
			this.btnSelectNone = new System.Windows.Forms.Button();
			this.btnInvert = new System.Windows.Forms.Button();
			this.panel1.SuspendLayout();
			this.SuspendLayout();
			// 
			// listBlips
			// 
			this.listBlips.CheckBoxes = true;
			this.listBlips.Columns.AddRange(new System.Windows.Forms.ColumnHeader[] {
																						this.colBlipsName,
																						this.colBlipsDistrict,
																						this.colBlipsX,
																						this.colBlipsY,
																						this.colBlipsZ});
			this.listBlips.Dock = System.Windows.Forms.DockStyle.Fill;
			this.listBlips.FullRowSelect = true;
			this.listBlips.Location = new System.Drawing.Point(0, 0);
			this.listBlips.Name = "listBlips";
			this.listBlips.Size = new System.Drawing.Size(580, 249);
			this.listBlips.TabIndex = 1;
			this.listBlips.View = System.Windows.Forms.View.Details;
			// 
			// colBlipsName
			// 
			this.colBlipsName.Text = "Name";
			this.colBlipsName.Width = 200;
			// 
			// colBlipsDistrict
			// 
			this.colBlipsDistrict.Text = "District";
			this.colBlipsDistrict.Width = 120;
			// 
			// colBlipsX
			// 
			this.colBlipsX.Text = "X";
			this.colBlipsX.Width = 80;
			// 
			// colBlipsY
			// 
			this.colBlipsY.Text = "Y";
			this.colBlipsY.Width = 80;
			// 
			// colBlipsZ
			// 
			this.colBlipsZ.Text = "Z";
			this.colBlipsZ.Width = 80;
			// 
			// panel1
			// 
			this.panel1.Controls.Add(this.btnInvert);
			this.panel1.Controls.Add(this.btnSelectNone);
			this.panel1.Controls.Add(this.btnSelectAll);
			this.panel1.Controls.Add(this.btnCancel);
			this.panel1.Controls.Add(this.btnOK);
			this.panel1.Dock = System.Windows.Forms.DockStyle.Bottom;
			this.panel1.Location = new System.Drawing.Point(0, 249);
			this.panel1.Name = "panel1";
			this.panel1.Size = new System.Drawing.Size(580, 32);
			this.panel1.TabIndex = 2;
			// 
			// btnOK
			// 
			this.btnOK.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
			this.btnOK.Location = new System.Drawing.Point(420, 4);
			this.btnOK.Name = "btnOK";
			this.btnOK.TabIndex = 0;
			this.btnOK.Text = "&OK";
			// 
			// btnCancel
			// 
			this.btnCancel.Anchor = ((System.Windows.Forms.AnchorStyles)((System.Windows.Forms.AnchorStyles.Top | System.Windows.Forms.AnchorStyles.Right)));
			this.btnCancel.DialogResult = System.Windows.Forms.DialogResult.Cancel;
			this.btnCancel.Location = new System.Drawing.Point(500, 4);
			this.btnCancel.Name = "btnCancel";
			this.btnCancel.TabIndex = 1;
			this.btnCancel.Text = "&Cancel";
			// 
			// btnSelectAll
			// 
			this.btnSelectAll.Location = new System.Drawing.Point(8, 4);
			this.btnSelectAll.Name = "btnSelectAll";
			this.btnSelectAll.TabIndex = 2;
			this.btnSelectAll.Text = "Select &All";
			// 
			// btnSelectNone
			// 
			this.btnSelectNone.Location = new System.Drawing.Point(88, 4);
			this.btnSelectNone.Name = "btnSelectNone";
			this.btnSelectNone.TabIndex = 3;
			this.btnSelectNone.Text = "Select &None";
			// 
			// btnInvert
			// 
			this.btnInvert.Location = new System.Drawing.Point(168, 4);
			this.btnInvert.Name = "btnInvert";
			this.btnInvert.TabIndex = 4;
			this.btnInvert.Text = "&Invert";
			// 
			// FrmImport
			// 
			this.AcceptButton = this.btnOK;
			this.AutoScaleBaseSize = new System.Drawing.Size(5, 13);
			this.CancelButton = this.btnCancel;
			this.ClientSize = new System.Drawing.Size(580, 281);
			this.ControlBox = false;
			this.Controls.Add(this.listBlips);
			this.Controls.Add(this.panel1);
			this.Name = "FrmImport";
			this.ShowInTaskbar = false;
			this.StartPosition = System.Windows.Forms.FormStartPosition.CenterParent;
			this.Text = "Choose the Blips to Import";
			this.panel1.ResumeLayout(false);
			this.ResumeLayout(false);

		}
		#endregion
	}
}
