using System;
using System.Collections;	
using System.Windows.Forms;

namespace Classless.MXO.Blipper {
	/// <summary>Allows for user sorting of ListViews.</summary>
	public class ListViewColumnSorter : IComparer {
		private int columnToSort;
		private SortOrder orderOfSort;
		private CaseInsensitiveComparer objectCompare;

    
		/// <summary>Gets or sets the number of the column to which to apply the sorting operation.</summary>
		public int SortColumn {
			set { columnToSort = value; }
			get { return columnToSort; }
		}

		/// <summary>Gets or sets the order of sorting to apply.</summary>
		public SortOrder Order {
			set { orderOfSort = value; }
			get { return orderOfSort; }
		}


		/// <summary>Initializes an instance of ListViewColumnSorter.</summary>
		public ListViewColumnSorter() {
			columnToSort = 0;
			orderOfSort = SortOrder.None;
			objectCompare = new CaseInsensitiveComparer();
		}


		/// <summary>Compares the two objects passed using a case insensitive comparison.</summary>
		/// <param name="x">First object to be compared</param>
		/// <param name="y">Second object to be compared</param>
		/// <returns>The result of the comparison. "0" if equal, negative if 'x' is less than 'y' and positive if 'x' is greater than 'y'.</returns>
		public int Compare(object x, object y) {
			int compareResult;
			ListViewItem listviewX, listviewY;

			// Compare the values.
			listviewX = (ListViewItem)x;
			listviewY = (ListViewItem)y;
			compareResult = objectCompare.Compare(listviewX.SubItems[columnToSort].Text, listviewY.SubItems[columnToSort].Text);

			// Return the result.
			if (orderOfSort == SortOrder.Ascending) {
				return compareResult;
			} else if (orderOfSort == SortOrder.Descending) {
				return -compareResult;
			} else {
				return 0;
			}
		}
	}
}
